@@ -3,6 +3,8 @@ use Moose;
 use Moose::Util::TypeConstraints;
 use methods;
 
+# ABSTRACT: represent a Card object from Stripe
+
 union 'StripeCard', ['Str', 'Net::Stripe::Card', 'Net::Stripe::Token'];
 
 # Input fields
@@ -37,7 +39,6 @@ method form_fields {
     );
 }
 
-
 __PACKAGE__->meta->make_immutable;
 1;
 
@@ -45,4 +46,23 @@ __END__
 
 =pod
 
+=head1 NAME
+
+Net::Stripe::Card - represent a Card object from Stripe
+
+=head1 VERSION
+
+version 0.10
+
+=head1 AUTHOR
+
+Luke Closs
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Copyright 2011, Prime Radiant, Inc..
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
