@@ -4,6 +4,8 @@ use Moose::Util::TypeConstraints;
 use methods;
 extends 'Net::Stripe::Resource';
 
+# ABSTRACT: represent a Coupon object from Stripe
+
 union 'StripeCoupon', ['Str', 'Net::Stripe::Coupon'];
 
 has 'id'                 => (is => 'rw', isa => 'Maybe[Str]');
@@ -22,7 +24,6 @@ method form_fields {
     );
 }
 
-
 __PACKAGE__->meta->make_immutable;
 1;
 
@@ -30,4 +31,23 @@ __END__
 
 =pod
 
+=head1 NAME
+
+Net::Stripe::Coupon - represent a Coupon object from Stripe
+
+=head1 VERSION
+
+version 0.10
+
+=head1 AUTHOR
+
+Luke Closs
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Copyright 2011, Prime Radiant, Inc..
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
