@@ -3,6 +3,8 @@ use Moose;
 use methods;
 extends 'Net::Stripe::Resource';
 
+# ABSTRACT: represent a Customer object from Stripe
+
 # Customer creation args
 has 'email'       => (is => 'rw', isa => 'Maybe[Str]');
 has 'description' => (is => 'rw', isa => 'Maybe[Str]');
@@ -44,7 +46,6 @@ method form_fields {
     );
 }
 
-
 __PACKAGE__->meta->make_immutable;
 1;
 
@@ -52,4 +53,23 @@ __END__
 
 =pod
 
+=head1 NAME
+
+Net::Stripe::Customer - represent a Customer object from Stripe
+
+=head1 VERSION
+
+version 0.10
+
+=head1 AUTHOR
+
+Luke Closs
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Copyright 2011, Prime Radiant, Inc..
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
