@@ -3,6 +3,8 @@ use Moose;
 use methods;
 extends 'Net::Stripe::Resource';
 
+# ABSTRACT: represent an Invoice object from Stripe
+
 has 'id'            => ( is => 'ro', isa => 'Maybe[Str]' );
 has 'created'       => ( is => 'ro', isa => 'Maybe[Int]' );
 has 'subtotal'      => ( is => 'ro', isa => 'Maybe[Int]', required => 1 );
@@ -94,7 +96,6 @@ around BUILDARGS => sub {
     $class->$orig(%args);
 };
 
-
 __PACKAGE__->meta->make_immutable;
 1;
 
@@ -102,4 +103,23 @@ __END__
 
 =pod
 
+=head1 NAME
+
+Net::Stripe::Invoice - represent an Invoice object from Stripe
+
+=head1 VERSION
+
+version 0.10
+
+=head1 AUTHOR
+
+Luke Closs
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Copyright 2011, Prime Radiant, Inc..
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
