@@ -78,4 +78,23 @@ __END__
 
 =pod
 
+=head1 NAME
+
+Net::Stripe::Resource
+
+=head1 VERSION
+
+version 0.10
+
+=head1 AUTHOR
+
+Luke Closs
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Copyright 2011, Prime Radiant, Inc..
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
