@@ -3,6 +3,8 @@ use Moose;
 use methods;
 extends 'Net::Stripe::Resource';
 
+# ABSTRACT: represent a list of Subscriptions from Stripe
+
 has 'object' => (is => 'ro', isa => 'Str');
 has 'count'  => (is => 'ro', isa => 'Int'); # no longer included by default, see note below
 has 'url'    => (is => 'ro', isa => 'Str');
@@ -17,6 +19,25 @@ __PACKAGE__->meta->make_immutable;
 
 =pod
 
+=head1 NAME
+
+Net::Stripe::SubscriptionList - represent a list of Subscriptions from Stripe
+
+=head1 VERSION
+
+version 0.10
+
+=head1 AUTHOR
+
+Luke Closs
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Copyright 2011, Prime Radiant, Inc..
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
 __END__
